========
Examples
========

.. toctree::
  :maxdepth: 2


Refractive index and radius determination
-----------------------------------------

.. fancy_include:: cell_edge.py

.. fancy_include:: sphere_models.py

.. fancy_include:: imagefit_projection.py

.. fancy_include:: imagefit_rytov_sc.py


Other examples
--------------

- :ref:`Background correction <qpimage:example_background_mask_sphere>` based
  on the mask image determined with the convenience method
  :func:`qpsphere.cnvnc.bg_phase_mask_for_qpi`.
